//
void gO17n(){
  // g + 17O -> n + 16O
  // Photon Energy = 9.0 MeV
  //
  gROOT->Reset();
  
#define MAX_nentries 1000000;
  
  TString pstit;
  
  // define style here 
  // general parameters
  gStyle->SetOptDate(0);     gStyle->SetOptTitle(0);
  gStyle->SetStatColor(10);  gStyle->SetStatH(0.2);
  gStyle->SetStatW(0.3);     gStyle->SetOptStat(0); 
  
  // canvas parameters
  gStyle->SetFrameBorderMode(0);
  gStyle->SetFrameBorderSize(0);
  gStyle->SetFrameFillColor(0);
  gStyle->SetCanvasColor(0);
  
  //
  
  // pads parameters
  //  gStyle->SetPadColor(39); 
  gStyle->SetPadColor(0); 
  gStyle->SetPadBorderMode(0);
  gStyle->SetPadBorderSize(0);
  gStyle->SetPadBottomMargin(0.18);
  gStyle->SetPadRightMargin(0.10);
  gStyle->SetPadLeftMargin(0.14);
  gStyle->SetLabelSize(0.04,"x");
  gStyle->SetLabelSize(0.04,"y");
  gStyle->SetTitleXSize(0.08);
  gStyle->SetPaperSize(10,12);
  
  gStyle->SetOptLogx(0);
  gStyle->SetOptLogy(1);
  
  // gStyle->SetNdivisions(505);
  
  gStyle->SetTitleYOffset(0.8);
  gStyle->SetTitleYSize(0.10);
  gROOT->ForceStyle();  
  
  //// 
  
  Double_t Q = 4.143; // Q (MeV), Q= M_O(16) + M_n - M_O(17)
  
  //
  
  if (!gROOT->GetClass("TGenPhaseSpace")) gSystem.Load("libPhysics");
  
  Double_t M17O = 17.0 * 931.494061 - 0.809; // MeV, mass of 17O nucleus
  TLorentzVector target(0.0, 0.0, 0.0, M17O);
  
  Double_t NeutronMass = 1.0*931.494061 + 8.071; // MeV 
  Double_t O16Mass = 16.0*931.494061 - 4.737; // MeV 
  
  Double_t masses[2] = {NeutronMass, O16Mass} ; 
  //
  
  TH1F* h1  = new TH1F("h1","Neutron Energy", 900,0,9.0);
  TH1F* h2  = new TH1F("h2","^{16}O Energy", 50,0,500);
  
  TH2F* h5  = new TH2F("h5","^{16}O Energy vs Neutron Energy", 900,0,9.00,50,0,0.50);
  
  //// Generate Phase Space
  
  for (Int_t n=0; n<MAX_nentries; n++) {

    Double_t Eg = 9.0; // MeV
    
    TLorentzVector beam(0.0, 0.0, Eg, Eg);
    TLorentzVector W = beam + target;
    
    TGenPhaseSpace event;
    event.SetDecay(W, 2, masses);
    
    //
    
    Double_t weight1 = event.Generate();
     
    TLorentzVector *pNeutron = event.GetDecay(0);
    TLorentzVector *pO16 = event.GetDecay(1);
    
    //
    
    Double_t TN = pNeutron->E() - masses[0]; // MeV
    Double_t T16O =  (pO16->E() - masses[1]) * 1000.0; // keV
    
    
    h1->Fill(TN, weight1);
    h2->Fill(T16O, weight1);
    
    T16O = T16O / 1000.0; // MeV
    
    h5->Fill(TN, T16O, weight1);
    
  }
  
  Double_t scale = 1.0;
  h1->Scale(scale);
  h2->Scale(scale);
  h5->Scale(scale);  
  
  //
  
  TCanvas *g1 = new TCanvas("g1","Neutron Energy",40,40,700,500);
  
  g1->SetGrid();
  
  h1->SetMinimum(1.0e+00);
  h1->SetMaximum(1.0e+6);
  
  h1->GetXaxis()->CenterTitle();
  h1->GetXaxis()->SetTitleOffset(1.2);
  h1->GetXaxis()->SetTitleSize(0.06);
  TString tit = "Neutron Energy (MeV)";
  h1->GetXaxis()->SetTitle(tit.Data());
  
  h1->GetYaxis()->CenterTitle();
  h1->GetYaxis()->SetTitleOffset(1.0);
  h1->GetYaxis()->SetTitleSize(0.06);
  TString tit ="Neutrons";
  h1->GetYaxis()->SetTitle(tit.Data());
  
  h1->SetLineColor(kBlue);
  h1->SetLineWidth(2.0);
  h1->SetLineStyle(2);
  h1->Draw("");
  //
  leg = new TLegend(0.55,0.70,0.85,0.85);
  leg->SetFillColor(0);
  leg->SetShadowColor(0);
  leg->AddEntry(h1,"Neutron","L");
  leg->Draw();
  leg->SetHeader("E_{g} = 9.0 MeV");
  leg->Draw();
  //
  
  g1->cd();
  pstit = "gO17n_neutron";
  pstit += ".gif";
  g1->Print(pstit.Data());
   
  ////
  //
  
  TCanvas *g2 = new TCanvas("g2","Oxygen 16 Energy",40,40,700,500);
  
  g2->SetGrid();
  
  h2->SetMinimum(1.0e+00);
  h2->SetMaximum(1.0e+6);
  
  h2->GetXaxis()->CenterTitle();
  h2->GetXaxis()->SetTitleOffset(1.2);
  h2->GetXaxis()->SetTitleSize(0.06);
  TString tit = "^{16}O Energy (keV)";
  h2->GetXaxis()->SetTitle(tit.Data());
  
  h2->GetYaxis()->CenterTitle();
  h2->GetYaxis()->SetTitleOffset(1.0);
  h2->GetYaxis()->SetTitleSize(0.06);
  TString tit ="^{16}O";
  h2->GetYaxis()->SetTitle(tit.Data());
  
  h2->SetLineColor(kBlue);
  h2->SetLineWidth(2.0);
  h2->SetLineStyle(2);
  h2->Draw("");
  //
  
  g2->cd();
  pstit = "gO17n_16O";
  pstit += ".gif";
  g2->Print(pstit.Data());
  ////
  //
  
  TCanvas *g3 = new TCanvas("g3","Oxygen 16 Energy vs Neutron Energy",40,40,700,500);
  
  gPad->SetLogy(0);
  TStyle::SetPalette(1,0);
  g3->SetGrid();
  
  h5->GetXaxis()->CenterTitle();
  h5->GetXaxis()->SetTitleOffset(1.2);
  h5->GetXaxis()->SetTitleSize(0.06);
  TString tit = "Neutron Energy (MeV)";
  h5->GetXaxis()->SetTitle(tit.Data());

  h5->GetYaxis()->CenterTitle();
  h5->GetYaxis()->SetTitleOffset(1.0);
  h5->GetYaxis()->SetTitleSize(0.06);
  TString tit ="^{16}O Energy (keV)";
  h5->GetYaxis()->SetTitle(tit.Data());
  
  h5->SetLineColor(kBlue);
  h5->SetLineWidth(2.0);
  h5->SetLineStyle(2);
  h5->Draw("CONTZ");
  //
  
  g3->cd();
  pstit = "gO17n_16OvsNeutron";
  pstit += ".gif";
  g3->Print(pstit.Data());
  
}
